@@ -51,7 +51,6 @@ class Main(Application):
 
     def _setup_arguments(self) -> None:
         # @formatter:off
-
         self._with_chained_args('operation', 'the Vault operation to process') \
             .argument('list', 'list all entries matching the given filter criteria, if specified') \
                 .add_argument('filter', "filter the listed vault entries by it's name", nargs='*') \
@@ -78,6 +77,7 @@ class Main(Application):
                 VAULT_USER: {VaultConfig.INSTANCE.vault_user}
                 VAULT_FILE: {VaultConfig.INSTANCE.vault_file}
                 STARTED: {now("%Y-%m-%d %H:%M:%S")}
+        =======================================\n
         '''))
 
         signal.signal(signal.SIGINT, self._abort)
@@ -88,14 +88,14 @@ class Main(Application):
         return self._exec_application()
 
     def _cleanup(self) -> None:
-        """TODO"""
+        """Close and lock the vault"""
         self.vault.close()
         unlocked = self.vault.configs.unlocked_vault_file
         if os.path.exists(unlocked):
             os.remove(unlocked)
 
     def _abort(self, signum=0, frame=None) -> None:
-        """TODO"""
+        """Securely abort the execution of vault"""
         self._cleanup()
         self.exit(signum, frame)
 
