@@ -15,8 +15,8 @@
 """
 from typing import Optional, Set
 
-from hspylib.core.datasource.identity import Identity
-from hspylib.core.datasource.sqlite.sqlite_repository import SQLiteRepository
+from datasource.identity import Identity
+from datasource.sqlite.sqlite_repository import SQLiteRepository
 from hspylib.core.tools.text_tools import quote
 
 from vault.entity.vault_entry import VaultEntry
